@@ -9,10 +9,5 @@
  * @link     http://pear.horde.org/index.php?package=Notification
  */
 
-require_once 'Horde/Test/Autoload.php';
-
-/** Catch strict standards */
-error_reporting(E_ALL | E_STRICT);
-
 /** Needed for PEAR_Error. */
 @require_once 'PEAR.php';
