@@ -9,15 +9,10 @@
  * @link     http://pear.horde.org/index.php?package=Notification
  */
 
-/**
- * Prepare the test setup.
- */
-require_once dirname(__FILE__) . '/../../../Autoload.php';
-
 /**
  * Test the status event class.
  *
- * Copyright 2009-2011 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2012 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -28,7 +23,7 @@ require_once dirname(__FILE__) . '/../../../Autoload.php';
  * @license  http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @link     http://pear.horde.org/index.php?package=Notification
  */
-class Horde_Notification_Class_Notification_Event_StatusTest extends PHPUnit_Framework_TestCase
+class Horde_Notification_Class_Notification_Event_StatusTest extends Horde_Test_Case
 {
     public function testMethodTostringHasResultTheTextOfTheEvent()
     {
